/*
 * ============LICENSE_START=======================================================
 * ONAP
 * ================================================================================
 * Copyright (C) 2018 AT&T Intellectual Property. All rights reserved.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.onap.policy.common.utils.test;

public class PolicyAssert {

    /**
     * Should not instantiate this.
     */
    private PolicyAssert() {
        // do nothing
    }

    /**
     * Invokes a function that is expected to throw an exception.
     *
     * @param clazz class of exception that is expected
     * @param func function
     * @return object
     */
    public static <T> T assertException(Class<T> clazz, RunnableWithEx func) {
        try {
            func.run();
            throw new AssertionError("missing exception");

        } catch (Exception e) {
            try {
                return clazz.cast(e);

            } catch (ClassCastException e2) {
                throw new AssertionError("incorrect exception type", e2);
            }
        }
    }

    /**
     * Runnable that may throw an exception.
     */
    @FunctionalInterface
    public static interface RunnableWithEx {
        public void run() throws Exception;
    }
}
